"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createOnePage = exports.generateImportMap = void 0;
const one_page_1 = require("../templates/one-page");
const spectaclePackage = require(`${__dirname}/../../spectacle-package.json`);
const REACT_VERSION = spectaclePackage.devDependencies.react.replace('^', '');
const ESM_SH_VERSION = 'v121';
const generateImportMap = () => {
    const importMap = new Map();
    const { dependencies, peerDependencies } = spectaclePackage;
    importMap.set('htm', importUrl('htm', '^3'));
    importMap.set('spectacle', 'https://esm.sh/spectacle@10?bundle');
    const sortedDeps = Object.entries({
        ...dependencies,
        ...peerDependencies
    }).sort(([a], [b]) => a.localeCompare(b));
    for (const [pkg, version] of sortedDeps) {
        if (importMap.has(pkg))
            continue;
        importMap.set(pkg, importUrl(pkg, version));
        handlePackageExceptions(pkg, version, importMap);
    }
    return importMap;
};
exports.generateImportMap = generateImportMap;
const createOnePage = (name, lang) => {
    const importMap = (0, exports.generateImportMap)();
    return (0, one_page_1.onePageTemplate)({ importMap, name, lang });
};
exports.createOnePage = createOnePage;
const importUrl = (pkg, version, extra = '') => {
    if (pkg === 'react')
        version = REACT_VERSION;
    return `https://esm.sh/${ESM_SH_VERSION}/${pkg}@${version}${extra}?deps=react@${REACT_VERSION}`;
};
const handlePackageExceptions = (pkg, version, importMap) => {
    if (pkg === 'react')
        importMap.set(`${pkg}/jsx-runtime`, importUrl(pkg, version, '/jsx-runtime'));
    else if (pkg === 'react-syntax-highlighter') {
        importMap.set(`${pkg}/dist/cjs/styles/prism/vs-dark.js`, importUrl(pkg, version, '/dist/esm/styles/prism/vs-dark.js'));
        importMap.set(`${pkg}/dist/cjs/styles/prism/index.js`, importUrl(pkg, version, '/dist/esm/styles/prism/index.js'));
    }
};
